<?php

global $newproject_text;
$newproject_text = array (

'createnewproject'	=>	'Maak een nieuw project aan',
'projecttitle'		=>	'Project titel',
'themestyle'		=>	'Thema / Stijl',
'projectprefs'		=>	'Project Eigenschappen',
'defaultproject'	=>	'Standaard Project',
'projectlists'		=>	'Project lijsten',
'addnewproject'		=>	'Nieuw project toevoegen',
'showlogo'			=>	'Toon titel logo',
'intromessage'		=>	'Welkomstbericht',
'htmlallowed'		=>	'HTML code is toegestaan',
'createproject'		=>	'Maak een nieuw project',
'noone'				=>	'Niemand',
'defaultcatowner'	=>	'Standaard categorie eigenaar',
'createthisproject'	=>	'Maak dit project',
'nopermission'		=>	'Je hebt geen rechten om deze pagina te bekijken',

// Added in version 0.9.6
'inlineimages'		=>	'Toon plaatjes bijlagen inline',

// Added in version 0.9.7
'othersview'		=>	'Iedereen toestaan dit project te bekijken',
'allowanonopentask'     =>      'Anonieme gebruikers toestaan taken te openen',

);
?>
